from . import NotificationError
from .conf import get_manager

from pywebpush import webpush
from pywebpush import WebPushException


class WebPushError(NotificationError):
	pass


def get_subscription_info(application_id, uri, browser, auth, p256dh):
	url = get_manager().get_wp_post_url(application_id, browser)
	return {
		"endpoint": "%s/%s" % (url, uri),
		"keys": {
			"auth": auth,
			"p256dh": p256dh
		}
	}


def webpush_send_message(uri, message, browser, auth, p256dh, application_id=None, **kwargs):
	try:
		response = webpush(
			subscription_info=get_subscription_info(application_id, uri, browser, auth, p256dh),
			data=message,
			vapid_private_key=get_manager().get_wp_private_key(application_id),
			vapid_claims=get_manager().get_wp_claims(application_id),
			**kwargs)
		results = {"results": [{}]}
		if not response.ok:
			results["results"][0]['error'] = response.content
			results["results"][0]['original_registration_id'] = response.content
		else:
			results["success"] = 1
		return results
	except WebPushException as e:
		raise WebPushError(e.message)



# assert warnings are enabled
import warnings
warnings.simplefilter("ignore", Warning)


DATABASES = {
	"default": {
		"ENGINE": "django.db.backends.sqlite3",
	}
}

INSTALLED_APPS = [
	"django.contrib.admin",
	"django.contrib.auth",
	"django.contrib.contenttypes",
	"django.contrib.sessions",
	"django.contrib.sites",
	"push_notifications",
]

SITE_ID = 1
ROOT_URLCONF = "core.urls"

SECRET_KEY = "foobar"

PUSH_NOTIFICATIONS_SETTINGS = {}



# flake8: noqa


GCM_JSON = '{"cast_id":108,"success":1,"failure":0,"canonical_ids":0,"results":[{"message_id":"1:08"}]}'
GCM_JSON_ERROR_NOTREGISTERED = (
	'{"failure": 1, "canonical_ids": 0, "cast_id": 6358665107659088804, "results":'
	' [{"error": "NotRegistered"}]}'
)
GCM_JSON_ERROR_INVALIDREGISTRATION = (
	'{"failure": 1, "canonical_ids": 0, "cast_id": 6358665107659088804, "results":'
	' [{"error": "InvalidRegistration"}]}'
)
GCM_JSON_ERROR_MISMATCHSENDERID = (
	'{"success":0, "failure": 1, "canonical_ids": 0, "results":'
	' [{"error": "MismatchSenderId"}]}'
)
GCM_JSON_CANONICAL_ID = (
	'{"failure":0,"canonical_ids":1,"success":1,"cast_id":7173139966327257000,"results":'
	'[{"registration_id":"NEW_REGISTRATION_ID","message_id":"0:1440068396670935%6868637df9fd7ecd"}]}'
)
GCM_JSON_CANONICAL_ID_SAME_DEVICE = (
	'{"failure":0,"canonical_ids":1,"success":1,"cast_id":7173139966327257000,"results":'
	'[{"registration_id":"bar","message_id":"0:1440068396670935%6868637df9fd7ecd"}]}'
)

GCM_JSON_MULTIPLE = (
	'{"multicast_id":108,"success":2,"failure":0,"canonical_ids":0,"results":'
	'[{"message_id":"1:08"}, {"message_id": "1:09"}]}'
)
GCM_JSON_MULTIPLE_ERROR = (
	'{"success":1, "failure": 2, "canonical_ids": 0, "cast_id": 6358665107659088804, "results":'
	' [{"error": "NotRegistered"}, {"message_id": "0:1433830664381654%3449593ff9fd7ecd"}, '
	'{"error": "InvalidRegistration"}]}'
)
GCM_JSON_MULTIPLE_ERROR_B = (
	'{"success":1, "failure": 2, "canonical_ids": 0, "cast_id": 6358665107659088804, '
	'"results": [{"error": "MismatchSenderId"}, {"message_id": '
	'"0:1433830664381654%3449593ff9fd7ecd"}, {"error": "InvalidRegistration"}]}'
)
GCM_JSON_MULTIPLE_CANONICAL_ID = (
	'{"failure":0,"canonical_ids":1,"success":2,"multicast_id":7173139966327257000,"results":'
	'[{"registration_id":"NEW_REGISTRATION_ID","message_id":"0:1440068396670935%6868637df9fd7ecd"},'
	'{"message_id":"0:1440068396670937%6868637df9fd7ecd"}]}'
)
GCM_JSON_MULTIPLE_CANONICAL_ID_SAME_DEVICE = (
	'{"failure":0,"canonical_ids":1,"success":2,"multicast_id":7173139966327257000,'
	'"results":[{"registration_id":"bar","message_id":"0:1440068396670935%6868637df9fd7ecd"}'
	',{"message_id":"0:1440068396670937%6868637df9fd7ecd"}]}'
)
